@@ -20,7 +20,7 @@
 #define OPENBLAS_CORE_ARMV6 
 #define OPENBLAS_CHAR_CORENAME "ARMV6"
 #define OPENBLAS_GEMM_MULTITHREAD_THRESHOLD 4
-#define OPENBLAS_VERSION " OpenBLAS 0.3.15 "
+#define OPENBLAS_VERSION " OpenBLAS 0.3.17 "
 /*This is only for "make install" target.*/
 
 #if defined(OPENBLAS_OS_WINNT) || defined(OPENBLAS_OS_CYGWIN_NT) || defined(OPENBLAS_OS_INTERIX)
@@ -122,6 +122,9 @@ typedef int blasint;
 
 /* Inclusion of Linux-specific header is needed for definition of cpu_set_t. */
 #ifdef OPENBLAS_OS_LINUX
+#ifndef _GNU_SOURCE
+ #define _GNU_SOURCE
+#endif
 #include <sched.h>
 #endif
 #endif /* OPENBLAS_CONFIG_H */
